<template>
  <div class="verify-profile-container">
    <div class="verify-profile-card-wrapper">
      <div class="verify-profile-card">
        <!-- Header Section -->
        <div class="card-header">
          <div class="header-icon">
            <svg class="icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" 
                d="M9 12l2 2 4-4m5.618-4.016A11.955 11.955 0 0112 2.944a11.955 11.955 0 01-8.618 3.04A12.02 12.02 0 003 9c0 5.591 3.824 10.29 9 11.622 5.176-1.332 9-6.03 9-11.622 0-1.042-.133-2.052-.382-3.016z" />
            </svg>
          </div>
          <h2>Verify Your Profile</h2>
          <p>One last step to get started</p>
        </div>

        <!-- Content Section -->
        <div class="card-content">
          <div class="notice-illustration">
            <svg class="notice-icon" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" 
                d="M3 8l7.89 5.26a2 2 0 002.22 0L21 8M5 19h14a2 2 0 002-2V7a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z" />
            </svg>
          </div>
          <p class="notice-message">
            To continue using the system, please verify your profile. We've sent verification instructions to your email address.
          </p>
          
          <div class="action-buttons">
            <button class="button primary" @click="checkEmail">
              Open Email App
            </button>
          </div>
        </div>
      </div>

      <!-- Footer -->
      <p class="footer-text">
        Didn't receive the email? 
        <a href="#" class="support-link" @click.prevent="contactSupport">Contact support</a>
      </p>
    </div>
  </div>
</template>

<script>
export default {
  name: "VerifyProfile",
  methods: {
    checkEmail() {
      window.location.href = "mailto:";
    },
    resendVerification() {
      // Add resend verification logic here
    },
    contactSupport() {
      window.location.href = "mailto:petar@leadrius.com";
    }
  }
};
</script>

<style scoped>
.verify-profile-container {
  min-height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 1rem;
  background: linear-gradient(135deg, #f0f4ff 0%, #eef1ff 100%);
}

.verify-profile-card-wrapper {
  width: 100%;
  max-width: 440px;
}

.verify-profile-card {
  background: white;
  border-radius: 1rem;
  overflow: hidden;
  box-shadow: 0 10px 25px rgba(0, 0, 0, 0.1);
}

.card-header {
  background: linear-gradient(to right, #3b82f6, #4f46e5);
  padding: 2rem 1.5rem;
  text-align: center;
  color: white;
}

.header-icon {
  width: 4rem;
  height: 4rem;
  margin: 0 auto 1rem;
  background: rgba(255, 255, 255, 0.1);
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  backdrop-filter: blur(4px);
}

.card-header h2 {
  font-size: 1.5rem;
  font-weight: 700;
  margin: 0 0 0.5rem;
}

.card-header p {
  color: rgba(255, 255, 255, 0.9);
  margin: 0;
}

.card-content {
  padding: 2rem 1.5rem;
  text-align: center;
}

.notice-illustration {
  width: 6rem;
  height: 6rem;
  margin: 0 auto 1.5rem;
  color: #6b7280;
}

.notice-icon {
  width: 100%;
  height: 100%;
}

.notice-message {
  color: #4b5563;
  font-size: 1rem;
  line-height: 1.6;
  margin-bottom: 2rem;
}

.action-buttons {
  display: flex;
  flex-direction: column;
  gap: 1rem;
}

.button {
  display: inline-flex;
  width: 100%;
  padding: 0.875rem 1rem;
  border-radius: 0.5rem;
  font-weight: 500;
  justify-content: center;
  align-items: center;
  transition: all 0.2s;
  cursor: pointer;
  border: none;
  font-size: 1rem;
}

.button.primary {
  background: linear-gradient(to right, #3b82f6, #4f46e5);
  color: white;
  box-shadow: 0 4px 12px rgba(59, 130, 246, 0.25);
}

.button.primary:hover {
  background: linear-gradient(to right, #2563eb, #4338ca);
}

.button.secondary {
  background: white;
  color: #4b5563;
  border: 1px solid #e5e7eb;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}

.button.secondary:hover {
  background: #f9fafb;
  color: #374151;
}

.footer-text {
  text-align: center;
  color: #4b5563;
  font-size: 0.875rem;
  margin-top: 1rem;
}

.support-link {
  color: #3b82f6;
  text-decoration: none;
  font-weight: 500;
}

.support-link:hover {
  color: #2563eb;
}

.icon {
  width: 1.5rem;
  height: 1.5rem;
}

/* Responsive adjustments */
@media (max-width: 640px) {
  .verify-profile-container {
    padding: 1rem;
  }
  
  .card-header {
    padding: 1.5rem 1rem;
  }
  
  .card-content {
    padding: 1.5rem 1rem;
  }

  .notice-illustration {
    width: 5rem;
    height: 5rem;
  }
}
</style>